import { DataParser, VectorData } from 'geostyler-data';
import { JSONSchema4TypeName } from 'json-schema';
/**
 * Interface representing the parameters to be send to WFS
 */
export interface ReadParams {
    url: string;
    version: string;
    typeName: string;
    featureID?: string;
    propertyName?: string[];
    srsName?: string;
    maxFeatures?: number;
    fetchParams?: Object;
}
/**
 * Class implementing DataParser to fetch schema and sample data
 * using WFS requests (DescribeFeatureType resp. GetFeature)
 */
export declare class WfsDataParser implements DataParser {
    /**
     * The name of the WfsDataParser.
     */
    static title: string;
    title: string;
    service: string;
    /**
     * The name Processor is passed as an option to the xml2js parser and modifies
     * the tagName. It strips all namespaces from the tags.
     *
     * @param {string} name The originial tagName
     * @return {string} The modified tagName
     */
    tagNameProcessor(name: string): string;
    /**
     * Generate request parameter string for a passed object
     *
     * @param {Object} params Object holding request params
     * @return {string} The URI encoded request parameter string joined with &
     */
    generateRequestParamString(params: any): string;
    /**
     * Map XSD datatypes (SimpleType) to json schema data stypes
     *
     * @param qualifiedXsdDataType The XSD datatype as string (including namespace)
     * @returns {JSONSchema4TypeName} The corresponding JSON schema type name
     */
    mapXsdTypeToJsonDataType(qualifiedXsdDataType: string): JSONSchema4TypeName;
    /**
     * Fetch schema and sample data and transforms it to the GeoStyler data model.
     *
     * Currently, WFS service must support application/json as outputFormat
     * and needs CORS headers (only needed if WFS Service is not located on the same origin
     * as the component using this parser) to be available in responses
     *
     * @param wfsConfig The parameters of the WFS
     */
    readData({ url, version, typeName, maxFeatures, propertyName, featureID, srsName, fetchParams }: ReadParams): Promise<VectorData>;
}
export default WfsDataParser;
